# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: plugin.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'plugin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cplugin.proto\x12\x0b\x61pp4.plugin\"\x07\n\x05\x45mpty\"\xa4\x01\n\x08Manifest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x10\n\x08homepage\x18\x05 \x01(\t\x12\x0f\n\x07license\x18\x06 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x07 \x03(\t\x12\x1b\n\x13\x61nalyzer_rules_json\x18\x08 \x01(\x0c\"\x96\x01\n\rActionRequest\x12\x13\n\x0b\x61\x63tion_name\x18\x01 \x01(\t\x12\x10\n\x08trace_id\x18\x02 \x01(\t\x12\x11\n\tdata_json\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63onfig_json\x18\x04 \x01(\x0c\x12\x14\n\x0c\x63ontext_json\x18\x05 \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x07 \x01(\t\"Y\n\x0e\x41\x63tionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0bresult_json\x18\x02 \x01(\x0c\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\t\"\x91\x01\n\nActionMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0binputs_json\x18\x05 \x01(\x0c\x12\x14\n\x0coutputs_json\x18\x06 \x01(\x0c\x12\x15\n\rexamples_json\x18\x07 \x01(\x0c\"6\n\nActionList\x12(\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x17.app4.plugin.ActionMeta\"3\n\x0eProviderConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63onfig_json\x18\x02 \x01(\x0c\"\x1c\n\x0cProviderName\x12\x0c\n\x04name\x18\x01 \x01(\t\"2\n\x10ProviderResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\x9d\x01\n\x0eHealthResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x39\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32(.app4.plugin.HealthResponse.DetailsEntry\x1a.\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x0cPluginStatus\x12\'\n\x08manifest\x18\x01 \x01(\x0b\x32\x15.app4.plugin.Manifest\x12\x16\n\x0euptime_seconds\x18\x02 \x01(\x03\x12.\n\tresources\x18\x03 \x03(\x0b\x32\x1b.app4.plugin.PluginResource\x12\'\n\x05stats\x18\x04 \x01(\x0b\x32\x18.app4.plugin.PluginStats\"\x9e\x01\n\x0ePluginResource\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x33\n\x04info\x18\x04 \x03(\x0b\x32%.app4.plugin.PluginResource.InfoEntry\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdb\x01\n\x0bPluginStats\x12\x18\n\x10total_executions\x18\x01 \x01(\x03\x12\x12\n\nsuccessful\x18\x02 \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x03\x12\x16\n\x0e\x61vg_latency_ms\x18\x04 \x01(\x01\x12\x41\n\raction_counts\x18\x05 \x03(\x0b\x32*.app4.plugin.PluginStats.ActionCountsEntry\x1a\x33\n\x11\x41\x63tionCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x32\x91\x04\n\rPluginService\x12\x38\n\x0bGetManifest\x12\x12.app4.plugin.Empty\x1a\x15.app4.plugin.Manifest\x12H\n\rExecuteAction\x12\x1a.app4.plugin.ActionRequest\x1a\x1b.app4.plugin.ActionResponse\x12:\n\x0bListActions\x12\x12.app4.plugin.Empty\x1a\x17.app4.plugin.ActionList\x12J\n\x0cInitProvider\x12\x1b.app4.plugin.ProviderConfig\x1a\x1d.app4.plugin.ProviderResponse\x12I\n\rCloseProvider\x12\x19.app4.plugin.ProviderName\x1a\x1d.app4.plugin.ProviderResponse\x12\x39\n\x06Health\x12\x12.app4.plugin.Empty\x1a\x1b.app4.plugin.HealthResponse\x12\x32\n\x08Shutdown\x12\x12.app4.plugin.Empty\x1a\x12.app4.plugin.Empty\x12:\n\tGetStatus\x12\x12.app4.plugin.Empty\x1a\x19.app4.plugin.PluginStatusB,Z*gitlab.com/app4ai/app4-plugin-sdk/go/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'plugin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*gitlab.com/app4ai/app4-plugin-sdk/go/proto'
  _globals['_HEALTHRESPONSE_DETAILSENTRY']._loaded_options = None
  _globals['_HEALTHRESPONSE_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_PLUGINRESOURCE_INFOENTRY']._loaded_options = None
  _globals['_PLUGINRESOURCE_INFOENTRY']._serialized_options = b'8\001'
  _globals['_PLUGINSTATS_ACTIONCOUNTSENTRY']._loaded_options = None
  _globals['_PLUGINSTATS_ACTIONCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_EMPTY']._serialized_start=29
  _globals['_EMPTY']._serialized_end=36
  _globals['_MANIFEST']._serialized_start=39
  _globals['_MANIFEST']._serialized_end=203
  _globals['_ACTIONREQUEST']._serialized_start=206
  _globals['_ACTIONREQUEST']._serialized_end=356
  _globals['_ACTIONRESPONSE']._serialized_start=358
  _globals['_ACTIONRESPONSE']._serialized_end=447
  _globals['_ACTIONMETA']._serialized_start=450
  _globals['_ACTIONMETA']._serialized_end=595
  _globals['_ACTIONLIST']._serialized_start=597
  _globals['_ACTIONLIST']._serialized_end=651
  _globals['_PROVIDERCONFIG']._serialized_start=653
  _globals['_PROVIDERCONFIG']._serialized_end=704
  _globals['_PROVIDERNAME']._serialized_start=706
  _globals['_PROVIDERNAME']._serialized_end=734
  _globals['_PROVIDERRESPONSE']._serialized_start=736
  _globals['_PROVIDERRESPONSE']._serialized_end=786
  _globals['_HEALTHRESPONSE']._serialized_start=789
  _globals['_HEALTHRESPONSE']._serialized_end=946
  _globals['_HEALTHRESPONSE_DETAILSENTRY']._serialized_start=900
  _globals['_HEALTHRESPONSE_DETAILSENTRY']._serialized_end=946
  _globals['_PLUGINSTATUS']._serialized_start=949
  _globals['_PLUGINSTATUS']._serialized_end=1117
  _globals['_PLUGINRESOURCE']._serialized_start=1120
  _globals['_PLUGINRESOURCE']._serialized_end=1278
  _globals['_PLUGINRESOURCE_INFOENTRY']._serialized_start=1235
  _globals['_PLUGINRESOURCE_INFOENTRY']._serialized_end=1278
  _globals['_PLUGINSTATS']._serialized_start=1281
  _globals['_PLUGINSTATS']._serialized_end=1500
  _globals['_PLUGINSTATS_ACTIONCOUNTSENTRY']._serialized_start=1449
  _globals['_PLUGINSTATS_ACTIONCOUNTSENTRY']._serialized_end=1500
  _globals['_PLUGINSERVICE']._serialized_start=1503
  _globals['_PLUGINSERVICE']._serialized_end=2032
# @@protoc_insertion_point(module_scope)
