# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: registry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from app4_sdk.proto import plugin_pb2 as plugin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eregistry.proto\x12\rapp4.registry\x1a\x0cplugin.proto\"\xc8\x01\n\x0fRegisterRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12:\n\x06labels\x18\x05 \x03(\x0b\x32*.app4.registry.RegisterRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n\x10RegisterResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x13\n\x0b\x61ssigned_id\x18\x03 \x01(\t\"N\n\x11UnregisterRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\"\xcd\x01\n\x10HeartbeatRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0f\n\x07healthy\x18\x04 \x01(\x08\x12=\n\x07metrics\x18\x05 \x03(\x0b\x32,.app4.registry.HeartbeatRequest.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x11HeartbeatResponse\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x08\x12\x17\n\x0fshould_shutdown\x18\x02 \x01(\x08\x12\x12\n\ndeprecated\x18\x03 \x01(\x08\x12\x1b\n\x13\x64\x65precation_message\x18\x04 \x01(\t\x12\x1b\n\x13recommended_version\x18\x05 \x01(\t\"\xbe\x01\n\x0eResolveRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x1a\n\x12version_constraint\x18\x02 \x01(\t\x12\x46\n\rprefer_labels\x18\x03 \x03(\x0b\x32/.app4.registry.ResolveRequest.PreferLabelsEntry\x1a\x33\n\x11PreferLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x0fResolveResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x18\n\x10resolved_version\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"E\n\x13ListVersionsRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x19\n\x11include_unhealthy\x18\x02 \x01(\x08\"F\n\x14ListVersionsResponse\x12.\n\x08versions\x18\x01 \x03(\x0b\x32\x1c.app4.registry.PluginVersion\"\xb7\x01\n\rPluginVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x30\n\tinstances\x18\x02 \x03(\x0b\x32\x1d.app4.registry.PluginInstance\x12\x12\n\ndeprecated\x18\x03 \x01(\x08\x12\x1b\n\x13\x64\x65precation_message\x18\x04 \x01(\t\x12\x1b\n\x13recommended_version\x18\x05 \x01(\t\x12\x15\n\rdeprecated_at\x18\x06 \x01(\x03\"\xb6\x02\n\x0ePluginInstance\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0f\n\x07healthy\x18\x03 \x01(\x08\x12\x16\n\x0elast_heartbeat\x18\x04 \x01(\x03\x12\x39\n\x06labels\x18\x05 \x03(\x0b\x32).app4.registry.PluginInstance.LabelsEntry\x12;\n\x07metrics\x18\x06 \x03(\x0b\x32*.app4.registry.PluginInstance.MetricsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"(\n\x10SubscribeRequest\x12\x14\n\x0cplugin_names\x18\x01 \x03(\t\"\xa3\x02\n\rRegistryEvent\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.app4.registry.RegistryEvent.EventType\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\"}\n\tEventType\x12\x15\n\x11PLUGIN_REGISTERED\x10\x00\x12\x17\n\x13PLUGIN_UNREGISTERED\x10\x01\x12\x12\n\x0ePLUGIN_HEALTHY\x10\x02\x12\x14\n\x10PLUGIN_UNHEALTHY\x10\x03\x12\x16\n\x12VERSION_DEPRECATED\x10\x04\"\x8d\x01\n\x16RegistryHealthResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x15\n\rtotal_plugins\x18\x02 \x01(\x05\x12\x17\n\x0fhealthy_plugins\x18\x03 \x01(\x05\x12\x17\n\x0ftotal_instances\x18\x04 \x01(\x05\x12\x19\n\x11healthy_instances\x18\x05 \x01(\x05\"8\n\nPluginList\x12*\n\x07plugins\x18\x01 \x03(\x0b\x32\x19.app4.registry.PluginInfo\"j\n\nPluginInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x12\x61vailable_versions\x18\x02 \x03(\t\x12\x17\n\x0ftotal_instances\x18\x03 \x01(\x05\x12\x19\n\x11healthy_instances\x18\x04 \x01(\x05\"m\n\x17\x44\x65precateVersionRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x1b\n\x13recommended_version\x18\x04 \x01(\t\"V\n\x18\x44\x65precateVersionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x66\x66\x65\x63ted_instances\x18\x03 \x01(\x05\"K\n\x14RemoveVersionRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\"R\n\x15RemoveVersionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x19\n\x11removed_instances\x18\x03 \x01(\x05\"\xb6\x01\n\x16RegistryProviderConfig\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x15\n\rprovider_name\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfig_json\x18\x04 \x01(\x0c\x12\x0f\n\x07version\x18\x05 \x01(\x03\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nupdated_at\x18\x08 \x01(\x03\"\x81\x01\n\x1aStoreProviderConfigRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x15\n\rprovider_name\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfig_json\x18\x04 \x01(\x0c\x12\x12\n\ncreated_by\x18\x05 \x01(\t\"N\n\x1bStoreProviderConfigResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x03\"V\n\x18GetProviderConfigRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x15\n\rprovider_name\x18\x03 \x01(\t\"p\n\x19GetProviderConfigResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x35\n\x06\x63onfig\x18\x02 \x01(\x0b\x32%.app4.registry.RegistryProviderConfig\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"Y\n\x1b\x44\x65leteProviderConfigRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x15\n\rprovider_name\x18\x03 \x01(\t\"A\n\x1aListProviderConfigsRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\"U\n\x1bListProviderConfigsResponse\x12\x36\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32%.app4.registry.RegistryProviderConfig\"F\n\x1fSubscribeProviderConfigsRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\"\xfa\x01\n\x13ProviderConfigEvent\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.app4.registry.ProviderConfigEvent.EventType\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x13\n\x0bplugin_name\x18\x03 \x01(\t\x12\x15\n\rprovider_name\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\x03\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\"G\n\tEventType\x12\x12\n\x0e\x43ONFIG_CREATED\x10\x00\x12\x12\n\x0e\x43ONFIG_UPDATED\x10\x01\x12\x12\n\x0e\x43ONFIG_DELETED\x10\x02\"\x8f\x01\n\x0f\x43onnectionEvent\x12\x1a\n\x12plugin_instance_id\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x16\n\x0eplugin_version\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\"V\n\x16ListConnectionsRequest\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x17\n\x0finclude_history\x18\x03 \x01(\x08\"L\n\x17ListConnectionsResponse\x12\x31\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x1c.app4.registry.AppConnection\"\xcf\x01\n\rAppConnection\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x13\n\x0bplugin_name\x18\x03 \x01(\t\x12\x16\n\x0eplugin_version\x18\x04 \x01(\t\x12\x1a\n\x12plugin_instance_id\x18\x05 \x01(\t\x12\x16\n\x0eplugin_address\x18\x06 \x01(\t\x12\x14\n\x0c\x63onnected_at\x18\x07 \x01(\x03\x12\x15\n\rlast_activity\x18\x08 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\t \x01(\x08\x32\xb4\x0c\n\x15PluginRegistryService\x12K\n\x08Register\x12\x1e.app4.registry.RegisterRequest\x1a\x1f.app4.registry.RegisterResponse\x12\x42\n\nUnregister\x12 .app4.registry.UnregisterRequest\x1a\x12.app4.plugin.Empty\x12N\n\tHeartbeat\x12\x1f.app4.registry.HeartbeatRequest\x1a .app4.registry.HeartbeatResponse\x12O\n\x0eResolveVersion\x12\x1d.app4.registry.ResolveRequest\x1a\x1e.app4.registry.ResolveResponse\x12W\n\x0cListVersions\x12\".app4.registry.ListVersionsRequest\x1a#.app4.registry.ListVersionsResponse\x12L\n\tSubscribe\x12\x1f.app4.registry.SubscribeRequest\x1a\x1c.app4.registry.RegistryEvent0\x01\x12\x43\n\x06Health\x12\x12.app4.plugin.Empty\x1a%.app4.registry.RegistryHealthResponse\x12?\n\x0eListAllPlugins\x12\x12.app4.plugin.Empty\x1a\x19.app4.registry.PluginList\x12\x63\n\x10\x44\x65precateVersion\x12&.app4.registry.DeprecateVersionRequest\x1a\'.app4.registry.DeprecateVersionResponse\x12Z\n\rRemoveVersion\x12#.app4.registry.RemoveVersionRequest\x1a$.app4.registry.RemoveVersionResponse\x12l\n\x13StoreProviderConfig\x12).app4.registry.StoreProviderConfigRequest\x1a*.app4.registry.StoreProviderConfigResponse\x12\x66\n\x11GetProviderConfig\x12\'.app4.registry.GetProviderConfigRequest\x1a(.app4.registry.GetProviderConfigResponse\x12V\n\x14\x44\x65leteProviderConfig\x12*.app4.registry.DeleteProviderConfigRequest\x1a\x12.app4.plugin.Empty\x12l\n\x13ListProviderConfigs\x12).app4.registry.ListProviderConfigsRequest\x1a*.app4.registry.ListProviderConfigsResponse\x12p\n\x18SubscribeProviderConfigs\x12..app4.registry.SubscribeProviderConfigsRequest\x1a\".app4.registry.ProviderConfigEvent0\x01\x12\x43\n\rNotifyConnect\x12\x1e.app4.registry.ConnectionEvent\x1a\x12.app4.plugin.Empty\x12\x46\n\x10NotifyDisconnect\x12\x1e.app4.registry.ConnectionEvent\x1a\x12.app4.plugin.Empty\x12`\n\x0fListConnections\x12%.app4.registry.ListConnectionsRequest\x1a&.app4.registry.ListConnectionsResponseB,Z*gitlab.com/app4ai/app4-plugin-sdk/go/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*gitlab.com/app4ai/app4-plugin-sdk/go/proto'
  _globals['_REGISTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_REGISTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_HEARTBEATREQUEST_METRICSENTRY']._loaded_options = None
  _globals['_HEARTBEATREQUEST_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_RESOLVEREQUEST_PREFERLABELSENTRY']._loaded_options = None
  _globals['_RESOLVEREQUEST_PREFERLABELSENTRY']._serialized_options = b'8\001'
  _globals['_PLUGININSTANCE_LABELSENTRY']._loaded_options = None
  _globals['_PLUGININSTANCE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PLUGININSTANCE_METRICSENTRY']._loaded_options = None
  _globals['_PLUGININSTANCE_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERREQUEST']._serialized_start=48
  _globals['_REGISTERREQUEST']._serialized_end=248
  _globals['_REGISTERREQUEST_LABELSENTRY']._serialized_start=203
  _globals['_REGISTERREQUEST_LABELSENTRY']._serialized_end=248
  _globals['_REGISTERRESPONSE']._serialized_start=250
  _globals['_REGISTERRESPONSE']._serialized_end=321
  _globals['_UNREGISTERREQUEST']._serialized_start=323
  _globals['_UNREGISTERREQUEST']._serialized_end=401
  _globals['_HEARTBEATREQUEST']._serialized_start=404
  _globals['_HEARTBEATREQUEST']._serialized_end=609
  _globals['_HEARTBEATREQUEST_METRICSENTRY']._serialized_start=563
  _globals['_HEARTBEATREQUEST_METRICSENTRY']._serialized_end=609
  _globals['_HEARTBEATRESPONSE']._serialized_start=612
  _globals['_HEARTBEATRESPONSE']._serialized_end=756
  _globals['_RESOLVEREQUEST']._serialized_start=759
  _globals['_RESOLVEREQUEST']._serialized_end=949
  _globals['_RESOLVEREQUEST_PREFERLABELSENTRY']._serialized_start=898
  _globals['_RESOLVEREQUEST_PREFERLABELSENTRY']._serialized_end=949
  _globals['_RESOLVERESPONSE']._serialized_start=951
  _globals['_RESOLVERESPONSE']._serialized_end=1062
  _globals['_LISTVERSIONSREQUEST']._serialized_start=1064
  _globals['_LISTVERSIONSREQUEST']._serialized_end=1133
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=1135
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=1205
  _globals['_PLUGINVERSION']._serialized_start=1208
  _globals['_PLUGINVERSION']._serialized_end=1391
  _globals['_PLUGININSTANCE']._serialized_start=1394
  _globals['_PLUGININSTANCE']._serialized_end=1704
  _globals['_PLUGININSTANCE_LABELSENTRY']._serialized_start=203
  _globals['_PLUGININSTANCE_LABELSENTRY']._serialized_end=248
  _globals['_PLUGININSTANCE_METRICSENTRY']._serialized_start=563
  _globals['_PLUGININSTANCE_METRICSENTRY']._serialized_end=609
  _globals['_SUBSCRIBEREQUEST']._serialized_start=1706
  _globals['_SUBSCRIBEREQUEST']._serialized_end=1746
  _globals['_REGISTRYEVENT']._serialized_start=1749
  _globals['_REGISTRYEVENT']._serialized_end=2040
  _globals['_REGISTRYEVENT_EVENTTYPE']._serialized_start=1915
  _globals['_REGISTRYEVENT_EVENTTYPE']._serialized_end=2040
  _globals['_REGISTRYHEALTHRESPONSE']._serialized_start=2043
  _globals['_REGISTRYHEALTHRESPONSE']._serialized_end=2184
  _globals['_PLUGINLIST']._serialized_start=2186
  _globals['_PLUGINLIST']._serialized_end=2242
  _globals['_PLUGININFO']._serialized_start=2244
  _globals['_PLUGININFO']._serialized_end=2350
  _globals['_DEPRECATEVERSIONREQUEST']._serialized_start=2352
  _globals['_DEPRECATEVERSIONREQUEST']._serialized_end=2461
  _globals['_DEPRECATEVERSIONRESPONSE']._serialized_start=2463
  _globals['_DEPRECATEVERSIONRESPONSE']._serialized_end=2549
  _globals['_REMOVEVERSIONREQUEST']._serialized_start=2551
  _globals['_REMOVEVERSIONREQUEST']._serialized_end=2626
  _globals['_REMOVEVERSIONRESPONSE']._serialized_start=2628
  _globals['_REMOVEVERSIONRESPONSE']._serialized_end=2710
  _globals['_REGISTRYPROVIDERCONFIG']._serialized_start=2713
  _globals['_REGISTRYPROVIDERCONFIG']._serialized_end=2895
  _globals['_STOREPROVIDERCONFIGREQUEST']._serialized_start=2898
  _globals['_STOREPROVIDERCONFIGREQUEST']._serialized_end=3027
  _globals['_STOREPROVIDERCONFIGRESPONSE']._serialized_start=3029
  _globals['_STOREPROVIDERCONFIGRESPONSE']._serialized_end=3107
  _globals['_GETPROVIDERCONFIGREQUEST']._serialized_start=3109
  _globals['_GETPROVIDERCONFIGREQUEST']._serialized_end=3195
  _globals['_GETPROVIDERCONFIGRESPONSE']._serialized_start=3197
  _globals['_GETPROVIDERCONFIGRESPONSE']._serialized_end=3309
  _globals['_DELETEPROVIDERCONFIGREQUEST']._serialized_start=3311
  _globals['_DELETEPROVIDERCONFIGREQUEST']._serialized_end=3400
  _globals['_LISTPROVIDERCONFIGSREQUEST']._serialized_start=3402
  _globals['_LISTPROVIDERCONFIGSREQUEST']._serialized_end=3467
  _globals['_LISTPROVIDERCONFIGSRESPONSE']._serialized_start=3469
  _globals['_LISTPROVIDERCONFIGSRESPONSE']._serialized_end=3554
  _globals['_SUBSCRIBEPROVIDERCONFIGSREQUEST']._serialized_start=3556
  _globals['_SUBSCRIBEPROVIDERCONFIGSREQUEST']._serialized_end=3626
  _globals['_PROVIDERCONFIGEVENT']._serialized_start=3629
  _globals['_PROVIDERCONFIGEVENT']._serialized_end=3879
  _globals['_PROVIDERCONFIGEVENT_EVENTTYPE']._serialized_start=3808
  _globals['_PROVIDERCONFIGEVENT_EVENTTYPE']._serialized_end=3879
  _globals['_CONNECTIONEVENT']._serialized_start=3882
  _globals['_CONNECTIONEVENT']._serialized_end=4025
  _globals['_LISTCONNECTIONSREQUEST']._serialized_start=4027
  _globals['_LISTCONNECTIONSREQUEST']._serialized_end=4113
  _globals['_LISTCONNECTIONSRESPONSE']._serialized_start=4115
  _globals['_LISTCONNECTIONSRESPONSE']._serialized_end=4191
  _globals['_APPCONNECTION']._serialized_start=4194
  _globals['_APPCONNECTION']._serialized_end=4401
  _globals['_PLUGINREGISTRYSERVICE']._serialized_start=4404
  _globals['_PLUGINREGISTRYSERVICE']._serialized_end=5992
# @@protoc_insertion_point(module_scope)
